##  Intermediate Asset Strategy
In this strategy, an intermediate asset is created in Collibra to represent every relation between the fact sheets.
To configure the intermediate relation strategy, do the following:
  1. In the Collibra Integration Configuration area, go to the Relation Mapping tab.
  2. From the Relation Mapping Strategy drop-down list, choose Asset.
  3. In the Asset Inbox Domain field, specify the domain where the intermediate asset will be created.
  4. In the Asset Type field, specify the type of the asset for the intermediate asset being created.
  5. In the Asset Relation Mapping field, choose the relations of the intermediate asset to be mapped with the fact sheets.
  6. Additionally, you can also map fields on relations from SAP LeanIX to the attributes on the intermediate asset in Collibra through Asset Relation Field Mapping fields.
![Configuring Intermediate Relation Strategy](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27537eac7a44101499d4ea3fd0bdff2e_LowRes.png)
Configuring Intermediate Relation Strategy
![Relation Between Application and Data Object Mapped to Asset Choosing Intermediate Asset Strategy](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275412847a44101491ed86b4c06cca2a_LowRes.png)
Relation Between Application and Data Object Mapped to Relation Between Assets Choosing Intermediate Asset Strategy


YesNo
Send
